import QtQuick 2.15
import QtQuick.Layouts 1.3
import QtQuick.Controls 2.5

Rectangle {
    id: docDropArea
    width: 80
    height: 64
    color: Qt.rgba(255,255,255,0.25)
    radius: 4
    property string text: ""
    property string desc: ""
    property var titleControl
    property var imageSource

    signal droped(string url)

    ColumnLayout{
        spacing: 3
        Layout.fillWidth: parent
        anchors.centerIn: parent
        Image {
            Layout.alignment: Qt.AlignHCenter
            width: 24
            height: 24
            source: imageSource
        }

        Label {
            horizontalAlignment: Qt.AlignHCenter//文本居中
            Layout.fillWidth : true
            text : docDropArea.text
        }

    }

    DropArea {
        anchors.fill: parent
        onEntered: function(drag) {
            if (switchToTipsTimer.running) {
                switchToTipsTimer.stop()
            }
            docArea.isInDocDropArea = true
            if (titleControl)
                titleControl.text = desc
            docScaleAnimation.stop()
            docScaleAnimation.to =1.1
            docScaleAnimation.start()
            color = Qt.rgba(255,255,255,0.5)
        }

        onExited: function() {
            docArea.isInDocDropArea = false
            if (titleControl)
                titleControl.text = titleControl.defText
            docScaleAnimation.stop()
            docScaleAnimation.to =1.0
            docScaleAnimation.start()
            color = Qt.rgba(255,255,255,0.25)
        }

        onDropped: function(drop) {
            var urls = drop.urls
            if (urls.length !== 1)
                return

            droped(urls[0].toString())
            docScaleAnimation.stop()
            docScaleAnimation.to =1.0
            docScaleAnimation.start()
            color = Qt.rgba(255,255,255,0.25)
        }

        NumberAnimation {
            id : docScaleAnimation
            target: docDropArea
            property : "scale"
            duration : 200
            to : 1.1
        }

    }
}
